@@ -47,6 +47,7 @@ struct UICStruct {
 	gboolean dial;
 	gboolean gsm;
 	gboolean transformPlus;
+	gulong sigId;
 };
 typedef struct UICStruct UIComponents;
 
@@ -742,6 +743,16 @@ static void sendSMSToTree (UIComponents *uic) {
 	gn_lib_phone_close(state);
 }
 
+gboolean clearSMSTextView_cb(GtkTextView *smsTextView, GdkEventFocus *event, UIComponents *uic) {
+	GtkTextBuffer *buffer;
+	buffer = gtk_text_view_get_buffer(smsTextView);
+	gtk_text_buffer_set_text(buffer, "", -1);
+	gtk_text_buffer_set_modified (buffer, FALSE);
+	g_signal_handler_disconnect(G_OBJECT(smsTextView), uic->sigId);
+	return FALSE;
+}
+
+
 /**
  * Create the menu items needed for the drop down menu.
  */
@@ -914,11 +925,13 @@ int main( int argc, char *argv[] ) {
 	gtk_container_add(GTK_CONTAINER(scrolled_window), smsTextView);
 	gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(smsTextView), GTK_WRAP_WORD_CHAR);
 	
-	
 	buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(smsTextView));
+	gtk_text_buffer_set_text(buffer, _("Enter SMS Text here"), -1);
 	gtk_text_buffer_set_modified (buffer, FALSE);
 	g_signal_connect (G_OBJECT (buffer), "modified-changed", G_CALLBACK (smsBufferChanged_cb), (gpointer) uic);
 
+	uic->sigId = g_signal_connect (G_OBJECT (smsTextView), "focus-in-event", G_CALLBACK (clearSMSTextView_cb), (gpointer) uic);
+
 	gtk_table_attach_defaults( GTK_TABLE(table), scrolled_window, 0, 5, 4, 9);
 	
 	gtk_widget_show_all (GTK_WIDGET(appview));
